      implicit none
#include "Zmedia.h"
#include "ZepTrackp.h"
      record /epmedia/media
      integer::icon, how
      character(100)::file
      how =0 
      read(*, '(a)')  file

      call epBPgeneini(file, media, how)
c
c        < LPM region
c           pair
      call epCrePrSTbl1(media, media.cnst)
c           pair LPM
      LPMeffect =.true.
      call epCrePrSTblH(media, media.cnst)
      end

